@@ -43,7 +43,7 @@
 #include <math.h>
 #include <Rmath.h>
 #include <Rcpp.h>
-#include <R_ext/PrtUtil.h>
+#include <R_ext/Print.h>
 
 using namespace std;
 using namespace Rcpp;
